|ci| |coverage| |version| |wheel| |supported-versions| |supported-implementations|


.. |ci| image:: https://gitlab.com/OpenEPDA/openepda/badges/master/pipeline.svg
    :alt: Test status
    :target: https://gitlab.com/OpenEPDA/openepda/-/commits/master

.. |coverage| image:: https://gitlab.com/OpenEPDA/openepda/badges/master/coverage.svg
    :alt: Test coverage
    :target: https://gitlab.com/OpenEPDA/openepda/-/commits/master

.. |version| image:: https://badge.fury.io/py/openepda.svg
    :alt: PyPI Package latest release
    :target: https://badge.fury.io/py/openepda

.. |wheel| image:: https://img.shields.io/pypi/wheel/openepda.svg
    :alt: PyPI Wheel
    :target: https://pypi.python.org/pypi/openepda

.. |supported-versions| image:: https://img.shields.io/pypi/pyversions/openepda.svg
    :alt: Supported versions
    :target: https://pypi.python.org/pypi/openepda

.. |supported-implementations| image:: https://img.shields.io/pypi/implementation/openepda.svg
    :alt: Supported implementations
    :target: https://pypi.python.org/pypi/openepda

========
openepda
========

About openEPDA
==============

openEPDA™ is a collection of open standards to be used in electronic-photonic
design automation. These include definition of data interchange formats to
facilitate Foundry PDK distribution and easier simulation and measurement
data exchange between the parties involved in the PIC design chain.
Specification of the formats and the roadmap are available at
http://openepda.org/.

openepda package includes python-definitions of these standards,
reader/writers for the files, and other useful tooling.

Installation
============

From pypi
---------

1. Install the package from pypi:

    `$ pip install openepda`


Documentation
=============
Full API documentation is available at https://openepda.org/pypi_package/api.html.

Changes
=======
See `changes`_.

Authors
=======
See `authors`_.

License
=======
openEPDA is a trademark of TU/e and PITC. openEPDA is maintained by TU/e and
PITC. Authors and copyright for specific standards are provided on the
corresponding pages on https://openepda.org/.

.. _changes: CHANGES
.. _authors: AUTHORS
